==> maven_3.5.4.orig.tar.xz: maven-maven-3.5.4/maven-model-builder/src/test/java/org/apache/maven/model/interpolation/MavenBuildTimestampTest.java <==
package org.apache.maven.model.interpolation;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.util.Date;
import java.util.Properties;

import junit.framework.TestCase;

public class MavenBuildTimestampTest
    extends TestCase
{
    public void testMavenBuildTimestampUsesUTC()
    {
        Properties interpolationProperties = new Properties();
        interpolationProperties.setProperty( "maven.build.timestamp.format", "yyyyMMdd'T'HHmm'Z'" );
        MavenBuildTimestamp timestamp = new MavenBuildTimestamp( new Date(), interpolationProperties );
        String formattedTimestamp = timestamp.formattedTimestamp();
        assertTrue( "We expect the UTC marker at the end of the timestamp.", formattedTimestamp.endsWith( "Z" ) );
    }
}

==> maven_3.9.9.orig.tar.xz: maven-maven-3.9.9/maven-model-builder/src/test/java/org/apache/maven/model/interpolation/MavenBuildTimestampTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.model.interpolation;

import java.util.Date;
import java.util.Properties;

import junit.framework.TestCase;

public class MavenBuildTimestampTest extends TestCase {
    public void testMavenBuildTimestampUsesUTC() {
        Properties interpolationProperties = new Properties();
        interpolationProperties.setProperty("maven.build.timestamp.format", "yyyyMMdd'T'HHmm'Z'");
        MavenBuildTimestamp timestamp = new MavenBuildTimestamp(new Date(), interpolationProperties);
        String formattedTimestamp = timestamp.formattedTimestamp();
        assertTrue("We expect the UTC marker at the end of the timestamp.", formattedTimestamp.endsWith("Z"));
    }
}
